==> kolourpaint-17.12.0.tar.xz: kolourpaint-17.12.0/widgets/imagelib/effects/kpEffectBalanceWidget.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBalanceWidget_H
#define kpEffectBalanceWidget_H


#include "kpEffectWidgetBase.h"
#include "imagelib/kpImage.h"


class QLabel;

class QComboBox;
class KIntNumInput;



class kpEffectBalanceWidget : public kpEffectWidgetBase
{
Q_OBJECT

public:
    kpEffectBalanceWidget (bool actOnSelection, QWidget *parent);
    virtual ~kpEffectBalanceWidget ();

    QString caption () const Q_DECL_OVERRIDE;

    bool isNoOp () const Q_DECL_OVERRIDE;
    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;

    kpEffectCommandBase *createCommand (
        kpCommandEnvironment *cmdEnviron) const Q_DECL_OVERRIDE;

protected:
    int channels () const;

    int brightness () const;
    int contrast () const;
    int gamma () const;

protected slots:
    void recalculateGammaLabel ();

    void resetBrightness ();
    void resetContrast ();
    void resetGamma ();

    void resetAll ();

protected:
    KIntNumInput *m_brightnessInput,
                 *m_contrastInput,
                 *m_gammaInput;
    QLabel *m_gammaLabel;
    QComboBox *m_channelsComboBox;
};


#endif  // kpEffectBalanceWidget_H

==> kolourpaint-21.08.1.tar.xz: kolourpaint-21.08.1/widgets/imagelib/effects/kpEffectBalanceWidget.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBalanceWidget_H
#define kpEffectBalanceWidget_H


#include "kpEffectWidgetBase.h"
#include "imagelib/kpImage.h"


class QLabel;

class QComboBox;
class kpIntNumInput;



class kpEffectBalanceWidget : public kpEffectWidgetBase
{
Q_OBJECT

public:
    kpEffectBalanceWidget (bool actOnSelection, QWidget *parent);
    ~kpEffectBalanceWidget () override;

    QString caption () const override;

    bool isNoOp () const override;
    kpImage applyEffect (const kpImage &image) override;

    kpEffectCommandBase *createCommand (
        kpCommandEnvironment *cmdEnviron) const override;

protected:
    int channels () const;

    int brightness () const;
    int contrast () const;
    int gamma () const;

protected slots:
    void recalculateGammaLabel ();

    void resetBrightness ();
    void resetContrast ();
    void resetGamma ();

    void resetAll ();

protected:
    kpIntNumInput *m_brightnessInput,
                 *m_contrastInput,
                 *m_gammaInput;
    QLabel *m_gammaLabel;
    QComboBox *m_channelsComboBox;
};


#endif  // kpEffectBalanceWidget_H
